import java.awt.Color;
import java.awt.Graphics;
import java.awt.Image;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.JPanel;


public class Board extends JPanel{
	private Color skyColor = new Color(0,150,255);
	private Color groundColor = new Color(120,70,40);
	private int groundHeight = 700;
	private Image chtulhuImage[][] = new Image[2][10];
	private Image marineImage[] = new Image[10];
	private Image tankImage[] = new Image[10];
	private Image buildingImage;
	
	public Board(){
		super();
		// Load sprites
		try{
			this.chtulhuImage[0][0] = ImageIO.read(getClass().getResource("/sprites/chtulhu/stand.png"));
			this.chtulhuImage[0][1] = ImageIO.read(getClass().getResource("/sprites/chtulhu/walkr.png"));
			this.chtulhuImage[0][2] = ImageIO.read(getClass().getResource("/sprites/chtulhu/walkr2.png"));
			this.chtulhuImage[0][3] = ImageIO.read(getClass().getResource("/sprites/chtulhu/walkl.png"));
			this.chtulhuImage[0][4] = ImageIO.read(getClass().getResource("/sprites/chtulhu/walkl2.png"));
			this.chtulhuImage[0][5] = ImageIO.read(getClass().getResource("/sprites/chtulhu/attack.png"));
			this.chtulhuImage[0][6]= ImageIO.read(getClass().getResource("/sprites/chtulhu/attackr.png"));
			this.chtulhuImage[0][7]= ImageIO.read(getClass().getResource("/sprites/chtulhu/attackl.png"));
			this.chtulhuImage[0][9]= ImageIO.read(getClass().getResource("/sprites/chtulhu/dead.png"));
			
			this.chtulhuImage[1][0]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/stand.png"));
			this.chtulhuImage[1][1]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/walkr.png"));
			this.chtulhuImage[1][2]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/walkr2.png"));
			this.chtulhuImage[1][3]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/walkl.png"));
			this.chtulhuImage[1][4]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/walkl2.png"));
			this.chtulhuImage[1][5]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/attack.png"));
			this.chtulhuImage[1][6]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/attackr.png"));
			this.chtulhuImage[1][7]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/attackl.png"));
			this.chtulhuImage[1][9]= ImageIO.read(getClass().getResource("/sprites/chtulhu/evolution/dead.png"));
			
			this.marineImage[0]= ImageIO.read(getClass().getResource("/sprites/marine/marine.png"));
			this.marineImage[9]= ImageIO.read(getClass().getResource("/sprites/marine/dead.png"));
			this.marineImage[5]= ImageIO.read(getClass().getResource("/sprites/marine/attack.png"));
			this.marineImage[6]= ImageIO.read(getClass().getResource("/sprites/marine/attack.png"));
			this.marineImage[7]= ImageIO.read(getClass().getResource("/sprites/marine/attack.png"));
			
			this.tankImage[0]= ImageIO.read(getClass().getResource("/sprites/tank/tank.png"));
			this.tankImage[5]= ImageIO.read(getClass().getResource("/sprites/tank/fire.png"));
			this.tankImage[9]= ImageIO.read(getClass().getResource("/sprites/tank/dead.png"));
			
			this.buildingImage = ImageIO.read(getClass().getResource("/sprites/building/building.png"));
		} catch(IOException e){
			System.out.println("Error");
		}
	}
	
	public void paintComponent(Graphics g){		
		// draw the sky
		g.setColor(skyColor);
		g.fillRect(0, 0, this.getWidth(), this.getHeight());
		
		// draw the ground
		
		g.setColor(groundColor);
		g.fillRect(0, groundHeight, this.getWidth(), this.getHeight() - groundHeight);
		
		int crx = Game.getChtulhu().getX();
		int cx = this.getWidth() / 2 ;
		int shift = cx - crx;
		
		// draw some building
		
		Building b_array[] = Game.getBuildingArray();
		for (Building b : b_array){
			if (b == null)
				break;
			this.drawElement(g, buildingImage, b, shift, 1);
		}
		
		// draw some tank
		Tank t_array[] = Game.getTankArray();
		for (Tank t : t_array){
			if (t == null)
				break;
			this.drawElement(g, tankImage, t, shift, 1);
		}
		
		// draw some marine
		Marine m_array[] = Game.getMarineArray();
		for (Marine m : m_array){
			if (m == null)
				break;
			this.drawElement(g, marineImage, m, shift, 1);
		}
		
		// draw Chtulhu
		this.drawElement(g, chtulhuImage[Game.getChtulhu().getLevel()], Game.getChtulhu(), shift, Game.getChtulhu().getGrowFactor());
			
		// draw score
		
		g.setColor(Color.black);
		g.drawString("HP : " + Game.getChtulhu().getHp(), 30,30);
		g.drawString("SCORE : " + Game.getScore(), 30, 50);
		
		// draw message
		g.drawString(Game.getMessage(), this.getWidth()/8, this.getHeight()/4);
	}
	
	public void drawElement(Graphics g, Image img_array[], Element e, int shift, double factor){
		Image img = img_array[e.getState()];
		int imgW = (int)(factor * img.getWidth(this));
		int imgH = (int)(factor * img.getHeight(this));
		int draw_posX = e.getX() + shift - imgW/2;
		
		g.drawImage(img, draw_posX, groundHeight - imgH, imgW, imgH, this);
	}
	
	public void drawElement(Graphics g, Image img, Element e, int shift, double factor){
		int draw_posX = e.getX() + shift - img.getWidth(this)/2;
		g.drawImage(img, draw_posX, groundHeight - img.getHeight(this), (int)(factor * img.getWidth(this)), (int)(factor * img.getHeight(this)), this);
	}
}
