import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.Calendar;
import java.util.Random;

import javax.swing.JFrame;


public class Game {
	private static Marine marineArray[] = new Marine[100];
	private static Tank tankArray[] = new Tank[100];
	private static Building buildArray[] = new Building[100];
	private static Chtulhu chtulhu = new Chtulhu(0,0);
	
	private static Random generator = new Random(); 
	
	private static boolean leftPressed = false; 
	private static boolean rightPressed = false; 
	private static boolean pPressed = false;
	private static boolean spacePressed = false;
	private static boolean cAttacked = false;
	
	private static String message;
	private static long mtime;
	
	private static long score = 0;
	
	public Game(){
		JFrame frame = new JFrame();
		frame.setSize(1000, 800);
		frame.setFocusable(true);
		frame.setResizable(false);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setLocationRelativeTo(null);
		frame.setTitle("Tiny Chtulhu");
		Board b = new Board();
		frame.setContentPane(b);
		frame.setVisible(true);
		
		frame.addKeyListener(new KeyInputHandler());
		
		marineArray[0] = new Marine(300, 0);
		marineArray[1] = new Marine(700, 0);
		marineArray[2] = new Marine(650, 0);
		marineArray[3] = new Marine(530, 0);
		marineArray[4] = new Marine(1000, 0);
		marineArray[5] = new Marine(1800, 0);
		marineArray[6] = new Marine(1400, 0);
		marineArray[7] = new Marine(3000, 0);
		
		marineArray[8] = new Marine(2300, 0);
		marineArray[9] = new Marine(2700, 0);
		marineArray[10] = new Marine(2650, 0);
		marineArray[11] = new Marine(2530, 0);
		marineArray[12] = new Marine(21000, 0);
		marineArray[13] = new Marine(21800, 0);
		marineArray[14] = new Marine(21400, 0);
		marineArray[15] = new Marine(3000, 0);
		marineArray[16] = new Marine(4000, 0);
		marineArray[17] = new Marine(3800, 0);
		marineArray[18] = new Marine(3400, 0);
		marineArray[19] = new Marine(4200, 0);
		
		tankArray[0] = new Tank(1000);
		tankArray[1] = new Tank(3000);
		tankArray[2] = new Tank(1600);
		tankArray[3] = new Tank(2000);
		
		buildArray[0] = new Building(500);
		buildArray[1] = new Building(1300);
		buildArray[2] = new Building(1800);
		buildArray[3] = new Building(3000);
		buildArray[4] = new Building(5000);
		buildArray[5] = new Building(6000);
		buildArray[6] = new Building(8000);
		
		
		Game.setMessage("WELCOME TO YOU");
		
		mainLoop(b);
	}

	public static void main (String[] argv){
		
		Game g = new Game();
		
	}
	
	public static void mainLoop(Board b){
		while (true){
			
			if (! pPressed){ // pause?
				
				Game.updateMessage();
				Game.updateGame();
				
				// move chtulhu
				if (rightPressed && !leftPressed)
					chtulhu.moveX(chtulhu.getSpeed());
				if (leftPressed && !rightPressed)
					chtulhu.moveX(-chtulhu.getSpeed());
				if (!leftPressed && !rightPressed)
					chtulhu.moveX(0);
				
				// make chtulhu attack
				if (spacePressed && !cAttacked){
					chtulhu.attack();
					cAttacked = true;
				}
				
				for (Marine m : marineArray){
					if (m == null)
						break;
					if (m.isAlive())
						m.attack(chtulhu);
				}
				
				for (Tank t : tankArray){
					if (t == null)
						break;
					if (t.isAlive())
						t.attack(chtulhu);
				}
			}
			
			b.repaint();
			
			try {
				Thread.sleep(50);
			} catch (InterruptedException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
	
	private class KeyInputHandler extends KeyAdapter {
		public void keyTyped(KeyEvent e) {
			if (e.getKeyChar() == 27)
				System.exit(0);
			if (e.getKeyChar() == 'p')
				pPressed = !pPressed;
		}
		
		public void keyPressed(KeyEvent e){
			if (e.getKeyCode() == KeyEvent.VK_LEFT)
				leftPressed = true;
			if (e.getKeyCode() == KeyEvent.VK_RIGHT)
				rightPressed = true;
			if (e.getKeyChar() == ' '){
				spacePressed = true;
			}
		}
		
		public void keyReleased(KeyEvent e){
			if (e.getKeyCode() == KeyEvent.VK_LEFT)
				leftPressed = false;
			if (e.getKeyCode() == KeyEvent.VK_RIGHT)
				rightPressed = false;
			if (e.getKeyChar() == ' '){
				cAttacked = false;
				spacePressed = false;
			}
		}
	}
	
	public static Chtulhu getChtulhu(){
		return chtulhu;
	}
	
	public static Marine[] getMarineArray(){
		return marineArray;
	}
	
	public static Tank[] getTankArray(){
		return tankArray;
	}
	
	public static Building[] getBuildingArray(){
		return buildArray;
	}
	
	public static String getMessage(){
		return message;
	}

	public static void updateMessage(){
		if (Calendar.getInstance().getTimeInMillis() - mtime > 5000){
			Game.setMessage("");
		}
	}
	
	public static void setMessage(String s){
		message = s;
		mtime = Calendar.getInstance().getTimeInMillis();
	}
	
	public static long getScore(){
		return score;
	}
	
	public static void addToScore(int n){
		score += n;
	}
	
	public static void updateGame(){
		int min = chtulhu.getX() + 2000;
		int max = 4000;
		
		if (generator.nextInt() % 60 == 0){ // % of chance to make a new unit
			for (int i = 0; i < marineArray.length; i++){
				if (marineArray[i] == null || (marineArray[i].isDead() && Element.getDistance(marineArray[i], chtulhu) > 1000)){
					marineArray[i] = new Marine(generator.nextInt(max) + min, 0);
					break;
				}
			}
		}
		if (generator.nextInt() % 200 == 0){ // % of chance to make a new unit
			for (int i = 0; i < tankArray.length; i++){
				if (tankArray[i] == null || (tankArray[i].isDead() && Element.getDistance(tankArray[i], chtulhu) > 1000)){
					tankArray[i] = new Tank(generator.nextInt(max) + min);
					break;
				}
			}
		}
	}
}
